import fastifyPlugin from "fastify-plugin";
import { handleErrors, handleNotFoundError } from "./handlers.js";
import { kHttpErrorsEnhancedConfiguration, kHttpErrorsEnhancedResponseValidations } from "./interfaces.js";
import { addResponseValidation, compileResponseValidationSchema } from "./validation.js";
export * from "./handlers.js";
export * from "./interfaces.js";
export { convertValidationErrors, niceJoin, validationMessagesFormatters } from "./validation.js";
export const plugin = fastifyPlugin(function(instance, options, done) {
    const isProduction = process.env.NODE_ENV === "production";
    const convertResponsesValidationErrors = options.convertResponsesValidationErrors ?? !isProduction;
    const configuration = {
        hideUnhandledErrors: options.hideUnhandledErrors ?? isProduction,
        convertValidationErrors: options.convertValidationErrors ?? true,
        responseValidatorCustomizer: options.responseValidatorCustomizer,
        allowUndeclaredResponses: options.allowUndeclaredResponses ?? false,
        preHandler: typeof options.preHandler === "function" ? options.preHandler : undefined
    };
    instance.decorate(kHttpErrorsEnhancedConfiguration, null);
    instance.decorateRequest(kHttpErrorsEnhancedConfiguration, null);
    instance.addHook("onRequest", (request, _, done)=>{
        request[kHttpErrorsEnhancedConfiguration] = configuration;
        done();
    });
    instance.setErrorHandler(handleErrors);
    instance.setNotFoundHandler(handleNotFoundError);
    if (convertResponsesValidationErrors) {
        instance.decorate(kHttpErrorsEnhancedResponseValidations, []);
        instance.addHook("onRoute", addResponseValidation);
        instance.addHook("onReady", compileResponseValidationSchema.bind(instance, configuration));
    }
    done();
}, {
    name: "fastify-http-errors-enhanced"
});
export default plugin;
